pygeodesy.ellipsoidalBase

Package pygeodesy :: Module ellipsoidalBase |
[frames] | no frames]

# Module ellipsoidalBase

(INTERNAL) Private ellipsoidal base classes `CartesianEllipsoidalBase` and `LatLonEllipsoidalBase`.

A pure Python implementation of geodesy tools for ellipsoidal earth models, transcoded in part from JavaScript originals by (C) Chris Veness 2005-2024 and published under the same MIT Licence**, see for example latlon-ellipsoidal.

Version: 25.07.21

Classes
| CartesianEllipsoidalBase (INTERNAL) Base class for ellipsoidal `Cartesian`s.
| LatLonEllipsoidalBase (INTERNAL) Base class for ellipsoidal `LatLon`s.

Variables
| __all__ = `_ALL_LAZY.ellipsoidalBase`